@@ -5,6 +5,7 @@ module TomlRB
     def initialize(content, options = {})
       @hash = {}
       @visited_keys = []
+      @fully_defined_keys = []
       @current = @hash
       @symbolize_keys = options[:symbolize_keys]
 
@@ -19,18 +20,20 @@ module TomlRB
     # Read about the Visitor pattern
     # http://en.wikipedia.org/wiki/Visitor_pattern
     def visit_table_array(table_array)
+      @fully_defined_keys = []
       table_array_key = table_array.full_key
       @visited_keys.reject! { |k| k.start_with? table_array_key }
 
       @current = table_array.navigate_keys @hash, @symbolize_keys
     end
 
-    def visit_keygroup(keygroup)
-      @current = keygroup.navigate_keys @hash, @visited_keys, @symbolize_keys
+    def visit_table(table)
+      @fully_defined_keys = []
+      @current = table.navigate_keys @hash, @visited_keys, @symbolize_keys
     end
 
     def visit_keyvalue(keyvalue)
-      keyvalue.assign @current, @symbolize_keys
+      keyvalue.assign @current, @fully_defined_keys, @symbolize_keys
     end
   end
 end
